@@ -21,13 +21,10 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#ifdef HAVE_CONFIG_H
 #include <config.h>
-#endif
-
+#include <gtk/gtkstock.h>
 #include <libgnomedb/gnome-db-error-dialog.h>
 #include <libgnomedb/gnome-db-util.h>
-
 #include "gnome-db-intl.h"
 
 struct _GnomeDbErrorDialogPrivate {
@@ -105,6 +102,9 @@ gnome_db_error_dialog_class_init (GnomeDbErrorDialogClass *klass)
 static void
 gnome_db_error_dialog_init (GnomeDbErrorDialog *dialog, GnomeDbErrorDialogClass *klass)
 {
+	g_return_if_fail (GNOME_DB_IS_ERROR_DIALOG (dialog));
+
+	/* allocate private structure */
 	dialog->priv = g_new (GnomeDbErrorDialogPrivate, 1);
 	dialog->priv->title = NULL;
 
@@ -112,9 +112,9 @@ gnome_db_error_dialog_init (GnomeDbErrorDialog *dialog, GnomeDbErrorDialogClass
 	dialog->priv->error_widget = GNOME_DB_ERROR (gnome_db_error_new ());
 	gtk_widget_show (GTK_WIDGET (dialog->priv->error_widget));
 
-	gtk_dialog_add_button (GTK_DIALOG (dialog), _("Previous"), GTK_RESPONSE_YES);
-	gtk_dialog_add_button (GTK_DIALOG (dialog), _("Next"), GTK_RESPONSE_NO);
-	gtk_dialog_add_button (GTK_DIALOG (dialog), _("Close"), GTK_RESPONSE_CLOSE);
+	gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_GO_BACK, GTK_RESPONSE_YES);
+	gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_GO_FORWARD, GTK_RESPONSE_NO);
+	gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE);
 
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox),
 			    GTK_WIDGET (dialog->priv->error_widget),
@@ -187,13 +187,15 @@ gnome_db_error_dialog_finalize (GObject *object)
  * Returns: a pointer to the new widget, or NULL on error
  */
 GtkWidget*
-gnome_db_error_dialog_new (gchar* title)
+gnome_db_error_dialog_new (gchar *title)
 {
 	GnomeDbErrorDialog *dialog;
 
 	dialog = g_object_new (GNOME_DB_TYPE_ERROR_DIALOG, NULL);
 	if (title)
 		gnome_db_error_dialog_set_title (dialog, title);
+	gnome_window_icon_set_from_file (GTK_WINDOW (dialog),
+					 LIBGNOMEDB_PIXMAPSDIR "/gnome-db.png");
 
 	return GTK_WIDGET (dialog);
 }
