@@ -1,5 +1,5 @@
 /* GNOME DB library
- * Copyright (C) 1999-2001 The Free Software Foundation
+ * Copyright (C) 1999-2002 The GNOME Foundation.
  *
  * AUTHORS:
  *      Rodrigo Moya <rodrigo@gnome-db.org>
@@ -293,13 +293,13 @@ gnome_db_list_set_model (GnomeDbList *list, GdaDataModel *model, gint col)
 
 	row_count = gda_data_model_get_n_rows (model);
 	for (n = 0; n < row_count; n++) {
-		GdaValue *value;
+		const GdaValue *value;
 
 		value = gda_data_model_get_value_at (model, col, n);
 		if (value != NULL) {
 			gda_data_model_list_append_value (
 				GDA_DATA_MODEL_LIST (list->priv->data_model),
-				(const GdaValue *) value);
+				value);
 		}
 	}
 
