@@ -30,6 +30,7 @@
 #include <gtk/gtktoolbar.h>
 #include <gtk/gtktreemodel.h>
 #include <gtk/gtkwidget.h>
+#include <libgnomeui/gnome-popup-menu.h>
 
 G_BEGIN_DECLS
 
@@ -48,6 +49,9 @@ GtkWidget   *gnome_db_new_hseparator_widget (void);
 GtkWidget   *gnome_db_new_label_widget (const gchar *text);
 GtkWidget   *gnome_db_new_notebook_widget (void);
 GtkWidget   *gnome_db_new_option_menu_widget (void);
+GtkWidget   *gnome_db_new_popup_menu (GtkWidget *parent,
+				      GnomeUIInfo *ui_info,
+				      gpointer user_data);
 GtkWidget   *gnome_db_new_scrolled_window_widget (void);
 GtkWidget   *gnome_db_new_status_bar_widget (void);
 GtkWidget   *gnome_db_new_table_widget (gint rows, gint cols, gboolean homogenous);
@@ -75,6 +79,7 @@ void         gnome_db_text_insert_at_cursor (GtkTextView *text, const gchar *con
 void         gnome_db_text_paste_clipboard (GtkTextView *text);
 void         gnome_db_text_set_text (GtkTextView *text, const gchar *contents, gint len);
 
+gboolean     gnome_db_yes_no_dialog (GtkWidget *parent, const gchar *format, ...);
 void         gnome_db_show_error (const gchar *format, ...);
 
 G_END_DECLS
