@@ -82,8 +82,9 @@ window_destroyed_cb (GtkWidget *widget, gpointer user_data)
 }
 
 /*
- * GnomeDbWindow class interface
+ * GnomeDbWindow class implementation
  */
+
 static void
 gnome_db_window_class_init (GnomeDbWindowClass *klass)
 {
@@ -311,6 +312,19 @@ gnome_db_window_set_status (GnomeDbWindow *window, const gchar *status)
 	bonobo_ui_component_set_status (window->priv->ui_component, status, NULL);
 }
 
+/**
+ * gnome_db_window_get_ui_component
+ * @window: a #GnomeDbWindow widget.
+ *
+ * Return the #BonoboUIComponent associated with the given window.
+ */
+BonoboUIComponent *
+gnome_db_window_get_ui_component (GnomeDbWindow *window)
+{
+	g_return_val_if_fail (GNOME_DB_IS_WINDOW (window), NULL);
+	return window->priv->ui_component;
+}
+
 /**
  * gnome_db_window_get_ui_container
  */
