@@ -34,6 +34,7 @@
 #include <libgnomedb/gnome-db-dsn-config.h>
 #include <libgnomedb/gnome-db-error.h>
 #include <libgnomedb/gnome-db-error-dialog.h>
+#include <libgnomedb/gnome-db-form.h>
 #include <libgnomedb/gnome-db-gray-bar.h>
 #include <libgnomedb/gnome-db-grid.h>
 #include <libgnomedb/gnome-db-list.h>
@@ -41,6 +42,8 @@
 #include <libgnomedb/gnome-db-login-dialog.h>
 #include <libgnomedb/gnome-db-model.h>
 #include <libgnomedb/gnome-db-provider-selector.h>
+#include <libgnomedb/gnome-db-report-editor.h>
+#include <libgnomedb/gnome-db-stock.h>
 #include <libgnomedb/gnome-db-table-editor.h>
 #include <libgnomedb/gnome-db-util.h>
 #include <libgnomedb/gnome-db-window.h>
